Starling
========
Goodies for implementing services


More information about Starling:

|                  |                                           |
| -----------------|------------------------------------------ |
| Documentation    | http://starling.readthedocs.io/en/latest/ |
| Python package   | https://pypi.python.org/pypi/starling     |
